@@ -1,3 +1,5 @@
+from json import JSONDecodeError
+
 import requests
 
 from ._base_url import BASE_URL
@@ -21,10 +23,13 @@ def get_chat(chat_id: int) -> dict:
     """
     For get information of chat
     :param chat_id: int
-    :return: { "chat_id": chat_id, "lang": lang }
+    :return: { "chat_id": chat_id, "lang": lang } or {}}
     """
-    r = requests.get(f"{BASE_URL}/chats/{chat_id}")
-    return r.json()
+    try:
+        r = requests.get(f"{BASE_URL}/chats/{chat_id}")
+        return r.json()
+    except JSONDecodeError:
+        return {}
 
 
 def set_lang(chat_id: int, lang: str) -> int:
